%define anolis_release 1

Name:           lmdb
Version:        0.9.31
Release:        %{anolis_release}%{?dist}
Summary:        An ultra-fast, ultra-compact, crash-proof, key-value, embedded data store
License:        OpenLDAP
URL:            http://symas.com/mdb
Source0:        https://git.openldap.org/openldap/openldap/-/archive/LMDB_%{version}/lmdb-LMDB_%{version}.tar.gz
Source1:        lmdb.pc.in

Patch0:         lmdb-make.patch

BuildRequires:  gcc gcc-c++ make autoconf
BuildRequires:  doxygen

%description
LMDB is a Btree-based database management library modeled loosely on the BerkeleyDB API, 
but much simplified. The entire database is exposed in a memory map, 
and all data fetches return data directly from the mapped memory, so no malloc's 
or memcpy's occur during data fetches. As such, the library is extremely simple 
because it requires no page caching layer of its own, and it is extremely high performance 
and memory-efficient. It is also fully transactional with full ACID semantics, 
and when the memory map is read-only, the database integrity cannot be corrupted by 
stray pointer writes from application code.


%package        libs
Summary:        Shared libraries for lmdb

%description    libs
The lmdb-libs package contains shared libraries necessary for running
applications that use lmdb.

%package        devel
Summary:        Development files for lmdb
Requires:       %{name} = %{version}-%{release}

%description    devel
The lmdb-devel package contains libraries and header files for
developing applications that use lmdb.

%package        doc
Summary:        Documentation files for lmdb
BuildArch:      noarch

%description    doc
The lmdb-doc package contains automatically generated documentation for lmdb.


%prep
%autosetup -n openldap-LMDB_%{version}-ce201088de95d26fc0da36ba805bf2ddc2ba74ff -p1


%build
pushd libraries/lib%{name}
%set_build_flags
%make_build XCFLAGS="%{build_cflags}"
doxygen
rm -f Doxyfile
rm -rf man
popd


%install
pushd libraries/lib%{name}
mkdir -m 0755 -p %{buildroot}{%{_bindir},%{_includedir}}
mkdir -m 0755 -p %{buildroot}{%{_libdir}/pkgconfig,%{_mandir}/man1}
%make_install prefix=%{_prefix} libdir=%{_libdir} mandir=%{_mandir}
popd

sed -e 's:@PREFIX@:%{_prefix}:g' \
    -e 's:@EXEC_PREFIX@:%{_exec_prefix}:g' \
    -e 's:@LIBDIR@:%{_libdir}:g' \
    -e 's:@INCLUDEDIR@:%{_includedir}:g' \
    -e 's:@PACKAGE_VERSION@:%{version}:g' \
    %{SOURCE1} >lmdb.pc
install -Dpm 0644 -t %{buildroot}%{_libdir}/pkgconfig lmdb.pc

%generate_compatibility_deps

%check
pushd libraries/lib%{name}
rm -rf testdb
LD_LIBRARY_PATH=$PWD make test
popd


%files
%{_bindir}/mdb_copy
%{_bindir}/mdb_dump
%{_bindir}/mdb_load
%{_bindir}/mdb_stat
%{_mandir}/man1/mdb*

%files libs
%{_libdir}/liblmdb.so.*
%dir %{abidir}
%doc libraries/lib%{name}/COPYRIGHT
%doc libraries/lib%{name}/CHANGES
%license libraries/lib%{name}/LICENSE
%{abidir}/*.dump

%files devel
%{_includedir}/lmdb.h
%{_libdir}/liblmdb.so
%{_libdir}/pkgconfig/lmdb.pc

%files doc
%license libraries/lib%{name}/LICENSE
%doc libraries/lib%{name}/html
%doc libraries/lib%{name}/CHANGES
%doc libraries/lib%{name}/COPYRIGHT


%changelog
* Fri Dec 22 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.9.31-1
- update to version 0.9.31

* Wed Apr 12 2023 chen_yu_ao <m15927509890@163.com> - 0.9.29-4
- change spec file format

* Tue Oct 18 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.9.29-3
- optimise spec file

* Wed Mar 16 2022 Liwei Ge <liwei.glw@linux.alibaba.com> - 0.9.29-2
- Append suffix to library

* Thu Mar 10 2022 Liwei Ge <liwei.glw@linux.alibaba.com> - 0.9.29-1
- Init version from upstream v0.9.29
